# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CampaignRuleParameters(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignRuleParameters - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'operator': 'str',
            'value': 'str',
            'priority': 'str',
            'dialing_mode': 'str'
        }

        self.attribute_map = {
            'operator': 'operator',
            'value': 'value',
            'priority': 'priority',
            'dialing_mode': 'dialingMode'
        }

        self._operator = None
        self._value = None
        self._priority = None
        self._dialing_mode = None

    @property
    def operator(self):
        """
        Gets the operator of this CampaignRuleParameters.
        The operator for comparison. Required for a CampaignRuleCondition.

        :return: The operator of this CampaignRuleParameters.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this CampaignRuleParameters.
        The operator for comparison. Required for a CampaignRuleCondition.

        :param operator: The operator of this CampaignRuleParameters.
        :type: str
        """
        allowed_values = ["equals", "greaterThan", "greaterThanEqualTo", "lessThan", "lessThanEqualTo"]
        if operator.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for operator -> " + operator)
            self._operator = "outdated_sdk_version"
        else:
            self._operator = operator

    @property
    def value(self):
        """
        Gets the value of this CampaignRuleParameters.
        The value for comparison. Required for a CampaignRuleCondition.

        :return: The value of this CampaignRuleParameters.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this CampaignRuleParameters.
        The value for comparison. Required for a CampaignRuleCondition.

        :param value: The value of this CampaignRuleParameters.
        :type: str
        """
        
        self._value = value

    @property
    def priority(self):
        """
        Gets the priority of this CampaignRuleParameters.
        The priority to set a campaign to. Required for the 'setCampaignPriority' action.

        :return: The priority of this CampaignRuleParameters.
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this CampaignRuleParameters.
        The priority to set a campaign to. Required for the 'setCampaignPriority' action.

        :param priority: The priority of this CampaignRuleParameters.
        :type: str
        """
        allowed_values = ["1", "2", "3", "4", "5"]
        if priority.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for priority -> " + priority)
            self._priority = "outdated_sdk_version"
        else:
            self._priority = priority

    @property
    def dialing_mode(self):
        """
        Gets the dialing_mode of this CampaignRuleParameters.
        The dialing mode to set a campaign to. Required for the 'setCampaignDialingMode' action.

        :return: The dialing_mode of this CampaignRuleParameters.
        :rtype: str
        """
        return self._dialing_mode

    @dialing_mode.setter
    def dialing_mode(self, dialing_mode):
        """
        Sets the dialing_mode of this CampaignRuleParameters.
        The dialing mode to set a campaign to. Required for the 'setCampaignDialingMode' action.

        :param dialing_mode: The dialing_mode of this CampaignRuleParameters.
        :type: str
        """
        allowed_values = ["agentless", "preview", "power", "predictive", "progressive", "external"]
        if dialing_mode.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for dialing_mode -> " + dialing_mode)
            self._dialing_mode = "outdated_sdk_version"
        else:
            self._dialing_mode = dialing_mode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ShiftTradeMatchReviewResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ShiftTradeMatchReviewResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'initiating_user': 'ShiftTradeMatchReviewUserResponse',
            'receiving_user': 'ShiftTradeMatchReviewUserResponse',
            'violations': 'list[ShiftTradeMatchViolation]',
            'admin_review_violations': 'list[ShiftTradeMatchViolation]'
        }

        self.attribute_map = {
            'initiating_user': 'initiatingUser',
            'receiving_user': 'receivingUser',
            'violations': 'violations',
            'admin_review_violations': 'adminReviewViolations'
        }

        self._initiating_user = None
        self._receiving_user = None
        self._violations = None
        self._admin_review_violations = None

    @property
    def initiating_user(self):
        """
        Gets the initiating_user of this ShiftTradeMatchReviewResponse.
        Details for the initiatingUser side of the shift trade

        :return: The initiating_user of this ShiftTradeMatchReviewResponse.
        :rtype: ShiftTradeMatchReviewUserResponse
        """
        return self._initiating_user

    @initiating_user.setter
    def initiating_user(self, initiating_user):
        """
        Sets the initiating_user of this ShiftTradeMatchReviewResponse.
        Details for the initiatingUser side of the shift trade

        :param initiating_user: The initiating_user of this ShiftTradeMatchReviewResponse.
        :type: ShiftTradeMatchReviewUserResponse
        """
        
        self._initiating_user = initiating_user

    @property
    def receiving_user(self):
        """
        Gets the receiving_user of this ShiftTradeMatchReviewResponse.
        Details for the receivingUser side of the shift trade

        :return: The receiving_user of this ShiftTradeMatchReviewResponse.
        :rtype: ShiftTradeMatchReviewUserResponse
        """
        return self._receiving_user

    @receiving_user.setter
    def receiving_user(self, receiving_user):
        """
        Sets the receiving_user of this ShiftTradeMatchReviewResponse.
        Details for the receivingUser side of the shift trade

        :param receiving_user: The receiving_user of this ShiftTradeMatchReviewResponse.
        :type: ShiftTradeMatchReviewUserResponse
        """
        
        self._receiving_user = receiving_user

    @property
    def violations(self):
        """
        Gets the violations of this ShiftTradeMatchReviewResponse.
        Constraint violations introduced after being matched that would normally disallow a trade, but which can still be overridden by the shift trade administrator

        :return: The violations of this ShiftTradeMatchReviewResponse.
        :rtype: list[ShiftTradeMatchViolation]
        """
        return self._violations

    @violations.setter
    def violations(self, violations):
        """
        Sets the violations of this ShiftTradeMatchReviewResponse.
        Constraint violations introduced after being matched that would normally disallow a trade, but which can still be overridden by the shift trade administrator

        :param violations: The violations of this ShiftTradeMatchReviewResponse.
        :type: list[ShiftTradeMatchViolation]
        """
        
        self._violations = violations

    @property
    def admin_review_violations(self):
        """
        Gets the admin_review_violations of this ShiftTradeMatchReviewResponse.
        Constraint violations associated with this shift trade which require shift trade administrator review

        :return: The admin_review_violations of this ShiftTradeMatchReviewResponse.
        :rtype: list[ShiftTradeMatchViolation]
        """
        return self._admin_review_violations

    @admin_review_violations.setter
    def admin_review_violations(self, admin_review_violations):
        """
        Sets the admin_review_violations of this ShiftTradeMatchReviewResponse.
        Constraint violations associated with this shift trade which require shift trade administrator review

        :param admin_review_violations: The admin_review_violations of this ShiftTradeMatchReviewResponse.
        :type: list[ShiftTradeMatchViolation]
        """
        
        self._admin_review_violations = admin_review_violations

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BusinessUnitActivityCode(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BusinessUnitActivityCode - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'active': 'bool',
            'default_code': 'bool',
            'category': 'str',
            'length_in_minutes': 'int',
            'counts_as_paid_time': 'bool',
            'counts_as_work_time': 'bool',
            'agent_time_off_selectable': 'bool',
            'metadata': 'WfmVersionedEntityMetadata',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'active': 'active',
            'default_code': 'defaultCode',
            'category': 'category',
            'length_in_minutes': 'lengthInMinutes',
            'counts_as_paid_time': 'countsAsPaidTime',
            'counts_as_work_time': 'countsAsWorkTime',
            'agent_time_off_selectable': 'agentTimeOffSelectable',
            'metadata': 'metadata',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._active = None
        self._default_code = None
        self._category = None
        self._length_in_minutes = None
        self._counts_as_paid_time = None
        self._counts_as_work_time = None
        self._agent_time_off_selectable = None
        self._metadata = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this BusinessUnitActivityCode.
        The globally unique identifier for the object.

        :return: The id of this BusinessUnitActivityCode.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BusinessUnitActivityCode.
        The globally unique identifier for the object.

        :param id: The id of this BusinessUnitActivityCode.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this BusinessUnitActivityCode.


        :return: The name of this BusinessUnitActivityCode.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BusinessUnitActivityCode.


        :param name: The name of this BusinessUnitActivityCode.
        :type: str
        """
        
        self._name = name

    @property
    def active(self):
        """
        Gets the active of this BusinessUnitActivityCode.
        Whether this activity code is active or has been deleted

        :return: The active of this BusinessUnitActivityCode.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this BusinessUnitActivityCode.
        Whether this activity code is active or has been deleted

        :param active: The active of this BusinessUnitActivityCode.
        :type: bool
        """
        
        self._active = active

    @property
    def default_code(self):
        """
        Gets the default_code of this BusinessUnitActivityCode.
        Whether this is a default activity code

        :return: The default_code of this BusinessUnitActivityCode.
        :rtype: bool
        """
        return self._default_code

    @default_code.setter
    def default_code(self, default_code):
        """
        Sets the default_code of this BusinessUnitActivityCode.
        Whether this is a default activity code

        :param default_code: The default_code of this BusinessUnitActivityCode.
        :type: bool
        """
        
        self._default_code = default_code

    @property
    def category(self):
        """
        Gets the category of this BusinessUnitActivityCode.
        The category of the activity code

        :return: The category of this BusinessUnitActivityCode.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this BusinessUnitActivityCode.
        The category of the activity code

        :param category: The category of this BusinessUnitActivityCode.
        :type: str
        """
        allowed_values = ["OnQueueWork", "Break", "Meal", "Meeting", "OffQueueWork", "TimeOff", "Training", "Unavailable", "Unscheduled"]
        if category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for category -> " + category)
            self._category = "outdated_sdk_version"
        else:
            self._category = category

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this BusinessUnitActivityCode.
        The default length of the activity in minutes

        :return: The length_in_minutes of this BusinessUnitActivityCode.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this BusinessUnitActivityCode.
        The default length of the activity in minutes

        :param length_in_minutes: The length_in_minutes of this BusinessUnitActivityCode.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def counts_as_paid_time(self):
        """
        Gets the counts_as_paid_time of this BusinessUnitActivityCode.
        Whether an agent is paid while performing this activity

        :return: The counts_as_paid_time of this BusinessUnitActivityCode.
        :rtype: bool
        """
        return self._counts_as_paid_time

    @counts_as_paid_time.setter
    def counts_as_paid_time(self, counts_as_paid_time):
        """
        Sets the counts_as_paid_time of this BusinessUnitActivityCode.
        Whether an agent is paid while performing this activity

        :param counts_as_paid_time: The counts_as_paid_time of this BusinessUnitActivityCode.
        :type: bool
        """
        
        self._counts_as_paid_time = counts_as_paid_time

    @property
    def counts_as_work_time(self):
        """
        Gets the counts_as_work_time of this BusinessUnitActivityCode.
        Indicates whether or not the activity should be counted as contiguous work time for calculating daily constraints

        :return: The counts_as_work_time of this BusinessUnitActivityCode.
        :rtype: bool
        """
        return self._counts_as_work_time

    @counts_as_work_time.setter
    def counts_as_work_time(self, counts_as_work_time):
        """
        Sets the counts_as_work_time of this BusinessUnitActivityCode.
        Indicates whether or not the activity should be counted as contiguous work time for calculating daily constraints

        :param counts_as_work_time: The counts_as_work_time of this BusinessUnitActivityCode.
        :type: bool
        """
        
        self._counts_as_work_time = counts_as_work_time

    @property
    def agent_time_off_selectable(self):
        """
        Gets the agent_time_off_selectable of this BusinessUnitActivityCode.
        Whether an agent can select this activity code when creating or editing a time off request. Null if the activity's category is not time off.

        :return: The agent_time_off_selectable of this BusinessUnitActivityCode.
        :rtype: bool
        """
        return self._agent_time_off_selectable

    @agent_time_off_selectable.setter
    def agent_time_off_selectable(self, agent_time_off_selectable):
        """
        Sets the agent_time_off_selectable of this BusinessUnitActivityCode.
        Whether an agent can select this activity code when creating or editing a time off request. Null if the activity's category is not time off.

        :param agent_time_off_selectable: The agent_time_off_selectable of this BusinessUnitActivityCode.
        :type: bool
        """
        
        self._agent_time_off_selectable = agent_time_off_selectable

    @property
    def metadata(self):
        """
        Gets the metadata of this BusinessUnitActivityCode.
        Version metadata of this activity code

        :return: The metadata of this BusinessUnitActivityCode.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this BusinessUnitActivityCode.
        Version metadata of this activity code

        :param metadata: The metadata of this BusinessUnitActivityCode.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    @property
    def self_uri(self):
        """
        Gets the self_uri of this BusinessUnitActivityCode.
        The URI for this object

        :return: The self_uri of this BusinessUnitActivityCode.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this BusinessUnitActivityCode.
        The URI for this object

        :param self_uri: The self_uri of this BusinessUnitActivityCode.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationVideoEventTopicCall(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationVideoEventTopicCall - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'recording': 'bool',
            'recording_state': 'str',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'error_info': 'QueueConversationVideoEventTopicErrorDetails',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'direction': 'str',
            'document_id': 'str',
            'pcSelf': 'QueueConversationVideoEventTopicAddress',
            'other': 'QueueConversationVideoEventTopicAddress',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'disconnect_reasons': 'list[QueueConversationVideoEventTopicDisconnectReason]',
            'fax_status': 'QueueConversationVideoEventTopicFaxStatus',
            'uui_data': 'str',
            'wrapup': 'QueueConversationVideoEventTopicWrapup',
            'after_call_work': 'QueueConversationVideoEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'agent_assistant_id': 'str',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'direction': 'direction',
            'document_id': 'documentId',
            'pcSelf': 'self',
            'other': 'other',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'disconnect_reasons': 'disconnectReasons',
            'fax_status': 'faxStatus',
            'uui_data': 'uuiData',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'agent_assistant_id': 'agentAssistantId',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._recording = None
        self._recording_state = None
        self._muted = None
        self._confined = None
        self._held = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._direction = None
        self._document_id = None
        self._pcSelf = None
        self._other = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._connected_time = None
        self._disconnected_time = None
        self._disconnect_reasons = None
        self._fax_status = None
        self._uui_data = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._agent_assistant_id = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationVideoEventTopicCall.


        :return: The id of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationVideoEventTopicCall.


        :param id: The id of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this QueueConversationVideoEventTopicCall.


        :return: The state of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationVideoEventTopicCall.


        :param state: The state of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "UPLOADING", "CONVERTING", "TRANSMITTING", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def recording(self):
        """
        Gets the recording of this QueueConversationVideoEventTopicCall.


        :return: The recording of this QueueConversationVideoEventTopicCall.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this QueueConversationVideoEventTopicCall.


        :param recording: The recording of this QueueConversationVideoEventTopicCall.
        :type: bool
        """
        
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this QueueConversationVideoEventTopicCall.


        :return: The recording_state of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this QueueConversationVideoEventTopicCall.


        :param recording_state: The recording_state of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        allowed_values = ["NONE", "ACTIVE", "PAUSED"]
        if recording_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for recording_state -> " + recording_state)
            self._recording_state = "outdated_sdk_version"
        else:
            self._recording_state = recording_state

    @property
    def muted(self):
        """
        Gets the muted of this QueueConversationVideoEventTopicCall.


        :return: The muted of this QueueConversationVideoEventTopicCall.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this QueueConversationVideoEventTopicCall.


        :param muted: The muted of this QueueConversationVideoEventTopicCall.
        :type: bool
        """
        
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this QueueConversationVideoEventTopicCall.


        :return: The confined of this QueueConversationVideoEventTopicCall.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this QueueConversationVideoEventTopicCall.


        :param confined: The confined of this QueueConversationVideoEventTopicCall.
        :type: bool
        """
        
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this QueueConversationVideoEventTopicCall.


        :return: The held of this QueueConversationVideoEventTopicCall.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationVideoEventTopicCall.


        :param held: The held of this QueueConversationVideoEventTopicCall.
        :type: bool
        """
        
        self._held = held

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationVideoEventTopicCall.


        :return: The error_info of this QueueConversationVideoEventTopicCall.
        :rtype: QueueConversationVideoEventTopicErrorDetails
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationVideoEventTopicCall.


        :param error_info: The error_info of this QueueConversationVideoEventTopicCall.
        :type: QueueConversationVideoEventTopicErrorDetails
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationVideoEventTopicCall.


        :return: The disconnect_type of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationVideoEventTopicCall.


        :param disconnect_type: The disconnect_type of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationVideoEventTopicCall.


        :return: The start_hold_time of this QueueConversationVideoEventTopicCall.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationVideoEventTopicCall.


        :param start_hold_time: The start_hold_time of this QueueConversationVideoEventTopicCall.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationVideoEventTopicCall.


        :return: The direction of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationVideoEventTopicCall.


        :param direction: The direction of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def document_id(self):
        """
        Gets the document_id of this QueueConversationVideoEventTopicCall.


        :return: The document_id of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this QueueConversationVideoEventTopicCall.


        :param document_id: The document_id of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._document_id = document_id

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this QueueConversationVideoEventTopicCall.


        :return: The pcSelf of this QueueConversationVideoEventTopicCall.
        :rtype: QueueConversationVideoEventTopicAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this QueueConversationVideoEventTopicCall.


        :param pcSelf: The pcSelf of this QueueConversationVideoEventTopicCall.
        :type: QueueConversationVideoEventTopicAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def other(self):
        """
        Gets the other of this QueueConversationVideoEventTopicCall.


        :return: The other of this QueueConversationVideoEventTopicCall.
        :rtype: QueueConversationVideoEventTopicAddress
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this QueueConversationVideoEventTopicCall.


        :param other: The other of this QueueConversationVideoEventTopicCall.
        :type: QueueConversationVideoEventTopicAddress
        """
        
        self._other = other

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationVideoEventTopicCall.


        :return: The provider of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationVideoEventTopicCall.


        :param provider: The provider of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationVideoEventTopicCall.


        :return: The script_id of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationVideoEventTopicCall.


        :param script_id: The script_id of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationVideoEventTopicCall.


        :return: The peer_id of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationVideoEventTopicCall.


        :param peer_id: The peer_id of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationVideoEventTopicCall.


        :return: The connected_time of this QueueConversationVideoEventTopicCall.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationVideoEventTopicCall.


        :param connected_time: The connected_time of this QueueConversationVideoEventTopicCall.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationVideoEventTopicCall.


        :return: The disconnected_time of this QueueConversationVideoEventTopicCall.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationVideoEventTopicCall.


        :param disconnected_time: The disconnected_time of this QueueConversationVideoEventTopicCall.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def disconnect_reasons(self):
        """
        Gets the disconnect_reasons of this QueueConversationVideoEventTopicCall.


        :return: The disconnect_reasons of this QueueConversationVideoEventTopicCall.
        :rtype: list[QueueConversationVideoEventTopicDisconnectReason]
        """
        return self._disconnect_reasons

    @disconnect_reasons.setter
    def disconnect_reasons(self, disconnect_reasons):
        """
        Sets the disconnect_reasons of this QueueConversationVideoEventTopicCall.


        :param disconnect_reasons: The disconnect_reasons of this QueueConversationVideoEventTopicCall.
        :type: list[QueueConversationVideoEventTopicDisconnectReason]
        """
        
        self._disconnect_reasons = disconnect_reasons

    @property
    def fax_status(self):
        """
        Gets the fax_status of this QueueConversationVideoEventTopicCall.


        :return: The fax_status of this QueueConversationVideoEventTopicCall.
        :rtype: QueueConversationVideoEventTopicFaxStatus
        """
        return self._fax_status

    @fax_status.setter
    def fax_status(self, fax_status):
        """
        Sets the fax_status of this QueueConversationVideoEventTopicCall.


        :param fax_status: The fax_status of this QueueConversationVideoEventTopicCall.
        :type: QueueConversationVideoEventTopicFaxStatus
        """
        
        self._fax_status = fax_status

    @property
    def uui_data(self):
        """
        Gets the uui_data of this QueueConversationVideoEventTopicCall.


        :return: The uui_data of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._uui_data

    @uui_data.setter
    def uui_data(self, uui_data):
        """
        Sets the uui_data of this QueueConversationVideoEventTopicCall.


        :param uui_data: The uui_data of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._uui_data = uui_data

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationVideoEventTopicCall.


        :return: The wrapup of this QueueConversationVideoEventTopicCall.
        :rtype: QueueConversationVideoEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationVideoEventTopicCall.


        :param wrapup: The wrapup of this QueueConversationVideoEventTopicCall.
        :type: QueueConversationVideoEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationVideoEventTopicCall.


        :return: The after_call_work of this QueueConversationVideoEventTopicCall.
        :rtype: QueueConversationVideoEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationVideoEventTopicCall.


        :param after_call_work: The after_call_work of this QueueConversationVideoEventTopicCall.
        :type: QueueConversationVideoEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationVideoEventTopicCall.


        :return: The after_call_work_required of this QueueConversationVideoEventTopicCall.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationVideoEventTopicCall.


        :param after_call_work_required: The after_call_work_required of this QueueConversationVideoEventTopicCall.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def agent_assistant_id(self):
        """
        Gets the agent_assistant_id of this QueueConversationVideoEventTopicCall.


        :return: The agent_assistant_id of this QueueConversationVideoEventTopicCall.
        :rtype: str
        """
        return self._agent_assistant_id

    @agent_assistant_id.setter
    def agent_assistant_id(self, agent_assistant_id):
        """
        Sets the agent_assistant_id of this QueueConversationVideoEventTopicCall.


        :param agent_assistant_id: The agent_assistant_id of this QueueConversationVideoEventTopicCall.
        :type: str
        """
        
        self._agent_assistant_id = agent_assistant_id

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationVideoEventTopicCall.


        :return: The additional_properties of this QueueConversationVideoEventTopicCall.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationVideoEventTopicCall.


        :param additional_properties: The additional_properties of this QueueConversationVideoEventTopicCall.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ConversationSocialExpressionEventTopicSocialMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationSocialExpressionEventTopicSocialMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'ConversationSocialExpressionEventTopicUriReference',
            'queue': 'ConversationSocialExpressionEventTopicUriReference',
            'team': 'ConversationSocialExpressionEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ConversationSocialExpressionEventTopicErrorBody',
            'script': 'ConversationSocialExpressionEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'ConversationSocialExpressionEventTopicUriReference',
            'external_organization': 'ConversationSocialExpressionEventTopicUriReference',
            'wrapup': 'ConversationSocialExpressionEventTopicWrapup',
            'conversation_routing_data': 'ConversationSocialExpressionEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'ConversationSocialExpressionEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'social_media_id': 'str',
            'social_media_hub': 'str',
            'social_user_name': 'str',
            'preview_text': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'social_media_id': 'socialMediaId',
            'social_media_hub': 'socialMediaHub',
            'social_user_name': 'socialUserName',
            'preview_text': 'previewText'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._social_media_id = None
        self._social_media_hub = None
        self._social_user_name = None
        self._preview_text = None

    @property
    def id(self):
        """
        Gets the id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param id: The id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param name: The name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The address of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param address: The address of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The start_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param start_time: The start_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The connected_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param connected_time: The connected_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The end_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param end_time: The end_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The start_hold_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param start_hold_time: The start_hold_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The purpose of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param purpose: The purpose of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param state: The state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The direction of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param direction: The direction of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The disconnect_type of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param disconnect_type: The disconnect_type of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The held of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param held: The held of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The wrapup_required of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param wrapup_required: The wrapup_required of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The wrapup_prompt of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The user of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param user: The user of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The queue of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param queue: The queue of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The team of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param team: The team of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The attributes of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param attributes: The attributes of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The error_info of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param error_info: The error_info of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The script of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param script: The script of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The wrapup_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The wrapup_skipped of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The alerting_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The provider of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param provider: The provider of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The external_contact of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param external_contact: The external_contact of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The external_organization of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param external_organization: The external_organization of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The wrapup of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param wrapup: The wrapup of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The conversation_routing_data of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The peer of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param peer: The peer of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The screen_recording_state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The flagged_reason of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param flagged_reason: The flagged_reason of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The journey_context of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: ConversationSocialExpressionEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param journey_context: The journey_context of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: ConversationSocialExpressionEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The start_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param start_acw_time: The start_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The end_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param end_acw_time: The end_acw_time of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def social_media_id(self):
        """
        Gets the social_media_id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The social_media_id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._social_media_id

    @social_media_id.setter
    def social_media_id(self, social_media_id):
        """
        Sets the social_media_id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param social_media_id: The social_media_id of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._social_media_id = social_media_id

    @property
    def social_media_hub(self):
        """
        Gets the social_media_hub of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The social_media_hub of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._social_media_hub

    @social_media_hub.setter
    def social_media_hub(self, social_media_hub):
        """
        Sets the social_media_hub of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param social_media_hub: The social_media_hub of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._social_media_hub = social_media_hub

    @property
    def social_user_name(self):
        """
        Gets the social_user_name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The social_user_name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._social_user_name

    @social_user_name.setter
    def social_user_name(self, social_user_name):
        """
        Sets the social_user_name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param social_user_name: The social_user_name of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._social_user_name = social_user_name

    @property
    def preview_text(self):
        """
        Gets the preview_text of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :return: The preview_text of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :rtype: str
        """
        return self._preview_text

    @preview_text.setter
    def preview_text(self, preview_text):
        """
        Sets the preview_text of this ConversationSocialExpressionEventTopicSocialMediaParticipant.


        :param preview_text: The preview_text of this ConversationSocialExpressionEventTopicSocialMediaParticipant.
        :type: str
        """
        
        self._preview_text = preview_text

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ShiftTradeMatchReviewUserResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ShiftTradeMatchReviewUserResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'weekly_minimum_paid_minutes': 'int',
            'weekly_maximum_paid_minutes': 'int',
            'pre_trade_schedule_paid_minutes': 'int',
            'post_trade_schedule_paid_minutes': 'int',
            'post_trade_new_shift': 'ShiftTradePreviewResponse'
        }

        self.attribute_map = {
            'weekly_minimum_paid_minutes': 'weeklyMinimumPaidMinutes',
            'weekly_maximum_paid_minutes': 'weeklyMaximumPaidMinutes',
            'pre_trade_schedule_paid_minutes': 'preTradeSchedulePaidMinutes',
            'post_trade_schedule_paid_minutes': 'postTradeSchedulePaidMinutes',
            'post_trade_new_shift': 'postTradeNewShift'
        }

        self._weekly_minimum_paid_minutes = None
        self._weekly_maximum_paid_minutes = None
        self._pre_trade_schedule_paid_minutes = None
        self._post_trade_schedule_paid_minutes = None
        self._post_trade_new_shift = None

    @property
    def weekly_minimum_paid_minutes(self):
        """
        Gets the weekly_minimum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The minimum weekly paid minutes for this user per the work plan tied to the agent schedule

        :return: The weekly_minimum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :rtype: int
        """
        return self._weekly_minimum_paid_minutes

    @weekly_minimum_paid_minutes.setter
    def weekly_minimum_paid_minutes(self, weekly_minimum_paid_minutes):
        """
        Sets the weekly_minimum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The minimum weekly paid minutes for this user per the work plan tied to the agent schedule

        :param weekly_minimum_paid_minutes: The weekly_minimum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :type: int
        """
        
        self._weekly_minimum_paid_minutes = weekly_minimum_paid_minutes

    @property
    def weekly_maximum_paid_minutes(self):
        """
        Gets the weekly_maximum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The maximum weekly paid minutes for this user per the work plan tied to the agent schedule

        :return: The weekly_maximum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :rtype: int
        """
        return self._weekly_maximum_paid_minutes

    @weekly_maximum_paid_minutes.setter
    def weekly_maximum_paid_minutes(self, weekly_maximum_paid_minutes):
        """
        Sets the weekly_maximum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The maximum weekly paid minutes for this user per the work plan tied to the agent schedule

        :param weekly_maximum_paid_minutes: The weekly_maximum_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :type: int
        """
        
        self._weekly_maximum_paid_minutes = weekly_maximum_paid_minutes

    @property
    def pre_trade_schedule_paid_minutes(self):
        """
        Gets the pre_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The paid minutes on the week schedule for this user prior to the shift trade

        :return: The pre_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :rtype: int
        """
        return self._pre_trade_schedule_paid_minutes

    @pre_trade_schedule_paid_minutes.setter
    def pre_trade_schedule_paid_minutes(self, pre_trade_schedule_paid_minutes):
        """
        Sets the pre_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The paid minutes on the week schedule for this user prior to the shift trade

        :param pre_trade_schedule_paid_minutes: The pre_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :type: int
        """
        
        self._pre_trade_schedule_paid_minutes = pre_trade_schedule_paid_minutes

    @property
    def post_trade_schedule_paid_minutes(self):
        """
        Gets the post_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The paid minutes on the week schedule for this user if the shift trade is approved

        :return: The post_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :rtype: int
        """
        return self._post_trade_schedule_paid_minutes

    @post_trade_schedule_paid_minutes.setter
    def post_trade_schedule_paid_minutes(self, post_trade_schedule_paid_minutes):
        """
        Sets the post_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        The paid minutes on the week schedule for this user if the shift trade is approved

        :param post_trade_schedule_paid_minutes: The post_trade_schedule_paid_minutes of this ShiftTradeMatchReviewUserResponse.
        :type: int
        """
        
        self._post_trade_schedule_paid_minutes = post_trade_schedule_paid_minutes

    @property
    def post_trade_new_shift(self):
        """
        Gets the post_trade_new_shift of this ShiftTradeMatchReviewUserResponse.
        Preview of what the shift will look like for the opposite side of this trade after the match is approved

        :return: The post_trade_new_shift of this ShiftTradeMatchReviewUserResponse.
        :rtype: ShiftTradePreviewResponse
        """
        return self._post_trade_new_shift

    @post_trade_new_shift.setter
    def post_trade_new_shift(self, post_trade_new_shift):
        """
        Sets the post_trade_new_shift of this ShiftTradeMatchReviewUserResponse.
        Preview of what the shift will look like for the opposite side of this trade after the match is approved

        :param post_trade_new_shift: The post_trade_new_shift of this ShiftTradeMatchReviewUserResponse.
        :type: ShiftTradePreviewResponse
        """
        
        self._post_trade_new_shift = post_trade_new_shift

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class NluDomain(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NluDomain - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'language': 'str',
            'draft_version': 'NluDomainVersion',
            'last_published_version': 'NluDomainVersion',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'language': 'language',
            'draft_version': 'draftVersion',
            'last_published_version': 'lastPublishedVersion',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._language = None
        self._draft_version = None
        self._last_published_version = None
        self._date_created = None
        self._date_modified = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this NluDomain.
        The globally unique identifier for the object.

        :return: The id of this NluDomain.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NluDomain.
        The globally unique identifier for the object.

        :param id: The id of this NluDomain.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this NluDomain.
        The name of the NLU domain.

        :return: The name of this NluDomain.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NluDomain.
        The name of the NLU domain.

        :param name: The name of this NluDomain.
        :type: str
        """
        
        self._name = name

    @property
    def language(self):
        """
        Gets the language of this NluDomain.
        The language culture of the NLU domain, e.g. `en-us`, `de-de`.

        :return: The language of this NluDomain.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this NluDomain.
        The language culture of the NLU domain, e.g. `en-us`, `de-de`.

        :param language: The language of this NluDomain.
        :type: str
        """
        
        self._language = language

    @property
    def draft_version(self):
        """
        Gets the draft_version of this NluDomain.
        The draft version of that NLU domain.

        :return: The draft_version of this NluDomain.
        :rtype: NluDomainVersion
        """
        return self._draft_version

    @draft_version.setter
    def draft_version(self, draft_version):
        """
        Sets the draft_version of this NluDomain.
        The draft version of that NLU domain.

        :param draft_version: The draft_version of this NluDomain.
        :type: NluDomainVersion
        """
        
        self._draft_version = draft_version

    @property
    def last_published_version(self):
        """
        Gets the last_published_version of this NluDomain.
        The last published version of that NLU domain.

        :return: The last_published_version of this NluDomain.
        :rtype: NluDomainVersion
        """
        return self._last_published_version

    @last_published_version.setter
    def last_published_version(self, last_published_version):
        """
        Sets the last_published_version of this NluDomain.
        The last published version of that NLU domain.

        :param last_published_version: The last_published_version of this NluDomain.
        :type: NluDomainVersion
        """
        
        self._last_published_version = last_published_version

    @property
    def date_created(self):
        """
        Gets the date_created of this NluDomain.
        The date when the NLU domain was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this NluDomain.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this NluDomain.
        The date when the NLU domain was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this NluDomain.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this NluDomain.
        The date when the NLU domain was updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this NluDomain.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this NluDomain.
        The date when the NLU domain was updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this NluDomain.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def self_uri(self):
        """
        Gets the self_uri of this NluDomain.
        The URI for this object

        :return: The self_uri of this NluDomain.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this NluDomain.
        The URI for this object

        :param self_uri: The self_uri of this NluDomain.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Survey(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Survey - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'conversation': 'Conversation',
            'survey_form': 'SurveyForm',
            'agent': 'DomainEntityRef',
            'status': 'str',
            'queue': 'QueueReference',
            'answers': 'SurveyScoringSet',
            'completed_date': 'datetime',
            'survey_error_details': 'SurveyErrorDetails',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'conversation': 'conversation',
            'survey_form': 'surveyForm',
            'agent': 'agent',
            'status': 'status',
            'queue': 'queue',
            'answers': 'answers',
            'completed_date': 'completedDate',
            'survey_error_details': 'surveyErrorDetails',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._conversation = None
        self._survey_form = None
        self._agent = None
        self._status = None
        self._queue = None
        self._answers = None
        self._completed_date = None
        self._survey_error_details = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Survey.
        The globally unique identifier for the object.

        :return: The id of this Survey.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Survey.
        The globally unique identifier for the object.

        :param id: The id of this Survey.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Survey.


        :return: The name of this Survey.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Survey.


        :param name: The name of this Survey.
        :type: str
        """
        
        self._name = name

    @property
    def conversation(self):
        """
        Gets the conversation of this Survey.


        :return: The conversation of this Survey.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this Survey.


        :param conversation: The conversation of this Survey.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def survey_form(self):
        """
        Gets the survey_form of this Survey.
        Survey form used for this survey.

        :return: The survey_form of this Survey.
        :rtype: SurveyForm
        """
        return self._survey_form

    @survey_form.setter
    def survey_form(self, survey_form):
        """
        Sets the survey_form of this Survey.
        Survey form used for this survey.

        :param survey_form: The survey_form of this Survey.
        :type: SurveyForm
        """
        
        self._survey_form = survey_form

    @property
    def agent(self):
        """
        Gets the agent of this Survey.


        :return: The agent of this Survey.
        :rtype: DomainEntityRef
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """
        Sets the agent of this Survey.


        :param agent: The agent of this Survey.
        :type: DomainEntityRef
        """
        
        self._agent = agent

    @property
    def status(self):
        """
        Gets the status of this Survey.


        :return: The status of this Survey.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Survey.


        :param status: The status of this Survey.
        :type: str
        """
        allowed_values = ["Pending", "Sent", "InProgress", "Finished", "OptOut", "Error", "Expired"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def queue(self):
        """
        Gets the queue of this Survey.


        :return: The queue of this Survey.
        :rtype: QueueReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this Survey.


        :param queue: The queue of this Survey.
        :type: QueueReference
        """
        
        self._queue = queue

    @property
    def answers(self):
        """
        Gets the answers of this Survey.


        :return: The answers of this Survey.
        :rtype: SurveyScoringSet
        """
        return self._answers

    @answers.setter
    def answers(self, answers):
        """
        Sets the answers of this Survey.


        :param answers: The answers of this Survey.
        :type: SurveyScoringSet
        """
        
        self._answers = answers

    @property
    def completed_date(self):
        """
        Gets the completed_date of this Survey.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The completed_date of this Survey.
        :rtype: datetime
        """
        return self._completed_date

    @completed_date.setter
    def completed_date(self, completed_date):
        """
        Sets the completed_date of this Survey.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param completed_date: The completed_date of this Survey.
        :type: datetime
        """
        
        self._completed_date = completed_date

    @property
    def survey_error_details(self):
        """
        Gets the survey_error_details of this Survey.
        Additional information about what happened when the survey is in Error status.

        :return: The survey_error_details of this Survey.
        :rtype: SurveyErrorDetails
        """
        return self._survey_error_details

    @survey_error_details.setter
    def survey_error_details(self, survey_error_details):
        """
        Sets the survey_error_details of this Survey.
        Additional information about what happened when the survey is in Error status.

        :param survey_error_details: The survey_error_details of this Survey.
        :type: SurveyErrorDetails
        """
        
        self._survey_error_details = survey_error_details

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Survey.
        The URI for this object

        :return: The self_uri of this Survey.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Survey.
        The URI for this object

        :param self_uri: The self_uri of this Survey.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SurveyForm(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SurveyForm - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'modified_date': 'datetime',
            'published': 'bool',
            'disabled': 'bool',
            'context_id': 'str',
            'language': 'str',
            'header': 'str',
            'footer': 'str',
            'question_groups': 'list[SurveyQuestionGroup]',
            'published_versions': 'DomainEntityListingSurveyForm',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'modified_date': 'modifiedDate',
            'published': 'published',
            'disabled': 'disabled',
            'context_id': 'contextId',
            'language': 'language',
            'header': 'header',
            'footer': 'footer',
            'question_groups': 'questionGroups',
            'published_versions': 'publishedVersions',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._modified_date = None
        self._published = None
        self._disabled = None
        self._context_id = None
        self._language = None
        self._header = None
        self._footer = None
        self._question_groups = None
        self._published_versions = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SurveyForm.
        The globally unique identifier for the object.

        :return: The id of this SurveyForm.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SurveyForm.
        The globally unique identifier for the object.

        :param id: The id of this SurveyForm.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SurveyForm.
        The survey form name

        :return: The name of this SurveyForm.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SurveyForm.
        The survey form name

        :param name: The name of this SurveyForm.
        :type: str
        """
        
        self._name = name

    @property
    def modified_date(self):
        """
        Gets the modified_date of this SurveyForm.
        Last modified date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this SurveyForm.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this SurveyForm.
        Last modified date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this SurveyForm.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def published(self):
        """
        Gets the published of this SurveyForm.
        Is this form published

        :return: The published of this SurveyForm.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this SurveyForm.
        Is this form published

        :param published: The published of this SurveyForm.
        :type: bool
        """
        
        self._published = published

    @property
    def disabled(self):
        """
        Gets the disabled of this SurveyForm.
        Is this form disabled

        :return: The disabled of this SurveyForm.
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """
        Sets the disabled of this SurveyForm.
        Is this form disabled

        :param disabled: The disabled of this SurveyForm.
        :type: bool
        """
        
        self._disabled = disabled

    @property
    def context_id(self):
        """
        Gets the context_id of this SurveyForm.
        Unique Id for all versions of this form

        :return: The context_id of this SurveyForm.
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """
        Sets the context_id of this SurveyForm.
        Unique Id for all versions of this form

        :param context_id: The context_id of this SurveyForm.
        :type: str
        """
        
        self._context_id = context_id

    @property
    def language(self):
        """
        Gets the language of this SurveyForm.
        Language for survey viewer localization. Currently localized languages: da, de, en-US, es, fi, fr, it, ja, ko, nl, no, pl, pt-BR, sv, th, tr, zh-CH, zh-TW

        :return: The language of this SurveyForm.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this SurveyForm.
        Language for survey viewer localization. Currently localized languages: da, de, en-US, es, fi, fr, it, ja, ko, nl, no, pl, pt-BR, sv, th, tr, zh-CH, zh-TW

        :param language: The language of this SurveyForm.
        :type: str
        """
        
        self._language = language

    @property
    def header(self):
        """
        Gets the header of this SurveyForm.
        Markdown text for the top of the form.

        :return: The header of this SurveyForm.
        :rtype: str
        """
        return self._header

    @header.setter
    def header(self, header):
        """
        Sets the header of this SurveyForm.
        Markdown text for the top of the form.

        :param header: The header of this SurveyForm.
        :type: str
        """
        
        self._header = header

    @property
    def footer(self):
        """
        Gets the footer of this SurveyForm.
        Markdown text for the bottom of the form.

        :return: The footer of this SurveyForm.
        :rtype: str
        """
        return self._footer

    @footer.setter
    def footer(self, footer):
        """
        Sets the footer of this SurveyForm.
        Markdown text for the bottom of the form.

        :param footer: The footer of this SurveyForm.
        :type: str
        """
        
        self._footer = footer

    @property
    def question_groups(self):
        """
        Gets the question_groups of this SurveyForm.
        A list of question groups

        :return: The question_groups of this SurveyForm.
        :rtype: list[SurveyQuestionGroup]
        """
        return self._question_groups

    @question_groups.setter
    def question_groups(self, question_groups):
        """
        Sets the question_groups of this SurveyForm.
        A list of question groups

        :param question_groups: The question_groups of this SurveyForm.
        :type: list[SurveyQuestionGroup]
        """
        
        self._question_groups = question_groups

    @property
    def published_versions(self):
        """
        Gets the published_versions of this SurveyForm.
        List of published version of this form

        :return: The published_versions of this SurveyForm.
        :rtype: DomainEntityListingSurveyForm
        """
        return self._published_versions

    @published_versions.setter
    def published_versions(self, published_versions):
        """
        Sets the published_versions of this SurveyForm.
        List of published version of this form

        :param published_versions: The published_versions of this SurveyForm.
        :type: DomainEntityListingSurveyForm
        """
        
        self._published_versions = published_versions

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SurveyForm.
        The URI for this object

        :return: The self_uri of this SurveyForm.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SurveyForm.
        The URI for this object

        :param self_uri: The self_uri of this SurveyForm.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class OutboundMessagingMessagingCampaignConfigChangeSmsConfig(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OutboundMessagingMessagingCampaignConfigChangeSmsConfig - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'message_column': 'str',
            'phone_column': 'str',
            'sender_sms_phone_number': 'OutboundMessagingMessagingCampaignConfigChangeSmsPhoneNumberRef',
            'content_template': 'OutboundMessagingMessagingCampaignConfigChangeResponseRef'
        }

        self.attribute_map = {
            'message_column': 'messageColumn',
            'phone_column': 'phoneColumn',
            'sender_sms_phone_number': 'senderSmsPhoneNumber',
            'content_template': 'contentTemplate'
        }

        self._message_column = None
        self._phone_column = None
        self._sender_sms_phone_number = None
        self._content_template = None

    @property
    def message_column(self):
        """
        Gets the message_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :return: The message_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :rtype: str
        """
        return self._message_column

    @message_column.setter
    def message_column(self, message_column):
        """
        Sets the message_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :param message_column: The message_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :type: str
        """
        
        self._message_column = message_column

    @property
    def phone_column(self):
        """
        Gets the phone_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :return: The phone_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :rtype: str
        """
        return self._phone_column

    @phone_column.setter
    def phone_column(self, phone_column):
        """
        Sets the phone_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :param phone_column: The phone_column of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :type: str
        """
        
        self._phone_column = phone_column

    @property
    def sender_sms_phone_number(self):
        """
        Gets the sender_sms_phone_number of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :return: The sender_sms_phone_number of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :rtype: OutboundMessagingMessagingCampaignConfigChangeSmsPhoneNumberRef
        """
        return self._sender_sms_phone_number

    @sender_sms_phone_number.setter
    def sender_sms_phone_number(self, sender_sms_phone_number):
        """
        Sets the sender_sms_phone_number of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :param sender_sms_phone_number: The sender_sms_phone_number of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :type: OutboundMessagingMessagingCampaignConfigChangeSmsPhoneNumberRef
        """
        
        self._sender_sms_phone_number = sender_sms_phone_number

    @property
    def content_template(self):
        """
        Gets the content_template of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :return: The content_template of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :rtype: OutboundMessagingMessagingCampaignConfigChangeResponseRef
        """
        return self._content_template

    @content_template.setter
    def content_template(self, content_template):
        """
        Sets the content_template of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.


        :param content_template: The content_template of this OutboundMessagingMessagingCampaignConfigChangeSmsConfig.
        :type: OutboundMessagingMessagingCampaignConfigChangeResponseRef
        """
        
        self._content_template = content_template

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Video(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Video - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'context': 'str',
            'audio_muted': 'bool',
            'video_muted': 'bool',
            'sharing_screen': 'bool',
            'peer_count': 'int',
            'disconnect_type': 'str',
            'start_alerting_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'provider': 'str',
            'peer_id': 'str',
            'msids': 'list[str]',
            'pcSelf': 'Address',
            'wrapup': 'Wrapup',
            'after_call_work': 'AfterCallWork',
            'after_call_work_required': 'bool'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'context': 'context',
            'audio_muted': 'audioMuted',
            'video_muted': 'videoMuted',
            'sharing_screen': 'sharingScreen',
            'peer_count': 'peerCount',
            'disconnect_type': 'disconnectType',
            'start_alerting_time': 'startAlertingTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'provider': 'provider',
            'peer_id': 'peerId',
            'msids': 'msids',
            'pcSelf': 'self',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired'
        }

        self._state = None
        self._id = None
        self._context = None
        self._audio_muted = None
        self._video_muted = None
        self._sharing_screen = None
        self._peer_count = None
        self._disconnect_type = None
        self._start_alerting_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._provider = None
        self._peer_id = None
        self._msids = None
        self._pcSelf = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None

    @property
    def state(self):
        """
        Gets the state of this Video.
        The connection state of this communication.

        :return: The state of this Video.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Video.
        The connection state of this communication.

        :param state: The state of this Video.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this Video.
        A globally unique identifier for this communication.

        :return: The id of this Video.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Video.
        A globally unique identifier for this communication.

        :param id: The id of this Video.
        :type: str
        """
        
        self._id = id

    @property
    def context(self):
        """
        Gets the context of this Video.
        The room id context (xmpp jid) for the conference session.

        :return: The context of this Video.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this Video.
        The room id context (xmpp jid) for the conference session.

        :param context: The context of this Video.
        :type: str
        """
        
        self._context = context

    @property
    def audio_muted(self):
        """
        Gets the audio_muted of this Video.
        Indicates whether this participant has muted their outgoing audio.

        :return: The audio_muted of this Video.
        :rtype: bool
        """
        return self._audio_muted

    @audio_muted.setter
    def audio_muted(self, audio_muted):
        """
        Sets the audio_muted of this Video.
        Indicates whether this participant has muted their outgoing audio.

        :param audio_muted: The audio_muted of this Video.
        :type: bool
        """
        
        self._audio_muted = audio_muted

    @property
    def video_muted(self):
        """
        Gets the video_muted of this Video.
        Indicates whether this participant has muted/paused their outgoing video.

        :return: The video_muted of this Video.
        :rtype: bool
        """
        return self._video_muted

    @video_muted.setter
    def video_muted(self, video_muted):
        """
        Sets the video_muted of this Video.
        Indicates whether this participant has muted/paused their outgoing video.

        :param video_muted: The video_muted of this Video.
        :type: bool
        """
        
        self._video_muted = video_muted

    @property
    def sharing_screen(self):
        """
        Gets the sharing_screen of this Video.
        Indicates whether this participant is sharing their screen to the session.

        :return: The sharing_screen of this Video.
        :rtype: bool
        """
        return self._sharing_screen

    @sharing_screen.setter
    def sharing_screen(self, sharing_screen):
        """
        Sets the sharing_screen of this Video.
        Indicates whether this participant is sharing their screen to the session.

        :param sharing_screen: The sharing_screen of this Video.
        :type: bool
        """
        
        self._sharing_screen = sharing_screen

    @property
    def peer_count(self):
        """
        Gets the peer_count of this Video.
        The number of peer participants from the perspective of the participant in the conference.

        :return: The peer_count of this Video.
        :rtype: int
        """
        return self._peer_count

    @peer_count.setter
    def peer_count(self, peer_count):
        """
        Sets the peer_count of this Video.
        The number of peer participants from the perspective of the participant in the conference.

        :param peer_count: The peer_count of this Video.
        :type: int
        """
        
        self._peer_count = peer_count

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Video.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :return: The disconnect_type of this Video.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Video.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :param disconnect_type: The disconnect_type of this Video.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "timeout", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_alerting_time(self):
        """
        Gets the start_alerting_time of this Video.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_alerting_time of this Video.
        :rtype: datetime
        """
        return self._start_alerting_time

    @start_alerting_time.setter
    def start_alerting_time(self, start_alerting_time):
        """
        Sets the start_alerting_time of this Video.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_alerting_time: The start_alerting_time of this Video.
        :type: datetime
        """
        
        self._start_alerting_time = start_alerting_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Video.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The connected_time of this Video.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Video.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param connected_time: The connected_time of this Video.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Video.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The disconnected_time of this Video.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Video.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param disconnected_time: The disconnected_time of this Video.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def provider(self):
        """
        Gets the provider of this Video.
        The source provider for the video.

        :return: The provider of this Video.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this Video.
        The source provider for the video.

        :param provider: The provider of this Video.
        :type: str
        """
        
        self._provider = provider

    @property
    def peer_id(self):
        """
        Gets the peer_id of this Video.
        The id of the peer communication corresponding to a matching leg for this communication.

        :return: The peer_id of this Video.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this Video.
        The id of the peer communication corresponding to a matching leg for this communication.

        :param peer_id: The peer_id of this Video.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def msids(self):
        """
        Gets the msids of this Video.
        List of media stream ids

        :return: The msids of this Video.
        :rtype: list[str]
        """
        return self._msids

    @msids.setter
    def msids(self, msids):
        """
        Sets the msids of this Video.
        List of media stream ids

        :param msids: The msids of this Video.
        :type: list[str]
        """
        
        self._msids = msids

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this Video.
        Address and name data for a call endpoint.

        :return: The pcSelf of this Video.
        :rtype: Address
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this Video.
        Address and name data for a call endpoint.

        :param pcSelf: The pcSelf of this Video.
        :type: Address
        """
        
        self._pcSelf = pcSelf

    @property
    def wrapup(self):
        """
        Gets the wrapup of this Video.
        Call wrap up or disposition data.

        :return: The wrapup of this Video.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this Video.
        Call wrap up or disposition data.

        :param wrapup: The wrapup of this Video.
        :type: Wrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this Video.
        After-call work for the communication.

        :return: The after_call_work of this Video.
        :rtype: AfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this Video.
        After-call work for the communication.

        :param after_call_work: The after_call_work of this Video.
        :type: AfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this Video.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :return: The after_call_work_required of this Video.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this Video.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :param after_call_work_required: The after_call_work_required of this Video.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessageInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessageInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'localizable_message_code': 'str',
            'message': 'str',
            'message_with_params': 'str',
            'message_params': 'dict(str, str)'
        }

        self.attribute_map = {
            'localizable_message_code': 'localizableMessageCode',
            'message': 'message',
            'message_with_params': 'messageWithParams',
            'message_params': 'messageParams'
        }

        self._localizable_message_code = None
        self._message = None
        self._message_with_params = None
        self._message_params = None

    @property
    def localizable_message_code(self):
        """
        Gets the localizable_message_code of this MessageInfo.
        Key that can be used to localize the message.

        :return: The localizable_message_code of this MessageInfo.
        :rtype: str
        """
        return self._localizable_message_code

    @localizable_message_code.setter
    def localizable_message_code(self, localizable_message_code):
        """
        Sets the localizable_message_code of this MessageInfo.
        Key that can be used to localize the message.

        :param localizable_message_code: The localizable_message_code of this MessageInfo.
        :type: str
        """
        
        self._localizable_message_code = localizable_message_code

    @property
    def message(self):
        """
        Gets the message of this MessageInfo.
        Description of the message.

        :return: The message of this MessageInfo.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this MessageInfo.
        Description of the message.

        :param message: The message of this MessageInfo.
        :type: str
        """
        
        self._message = message

    @property
    def message_with_params(self):
        """
        Gets the message_with_params of this MessageInfo.
        Message with template fields for variable replacement.

        :return: The message_with_params of this MessageInfo.
        :rtype: str
        """
        return self._message_with_params

    @message_with_params.setter
    def message_with_params(self, message_with_params):
        """
        Sets the message_with_params of this MessageInfo.
        Message with template fields for variable replacement.

        :param message_with_params: The message_with_params of this MessageInfo.
        :type: str
        """
        
        self._message_with_params = message_with_params

    @property
    def message_params(self):
        """
        Gets the message_params of this MessageInfo.
        Map with fields for variable replacement.

        :return: The message_params of this MessageInfo.
        :rtype: dict(str, str)
        """
        return self._message_params

    @message_params.setter
    def message_params(self, message_params):
        """
        Sets the message_params of this MessageInfo.
        Map with fields for variable replacement.

        :param message_params: The message_params of this MessageInfo.
        :type: dict(str, str)
        """
        
        self._message_params = message_params

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AuthzGrant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AuthzGrant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'subject_id': 'str',
            'division': 'AuthzDivision',
            'role': 'AuthzGrantRole',
            'grant_made_at': 'datetime'
        }

        self.attribute_map = {
            'subject_id': 'subjectId',
            'division': 'division',
            'role': 'role',
            'grant_made_at': 'grantMadeAt'
        }

        self._subject_id = None
        self._division = None
        self._role = None
        self._grant_made_at = None

    @property
    def subject_id(self):
        """
        Gets the subject_id of this AuthzGrant.


        :return: The subject_id of this AuthzGrant.
        :rtype: str
        """
        return self._subject_id

    @subject_id.setter
    def subject_id(self, subject_id):
        """
        Sets the subject_id of this AuthzGrant.


        :param subject_id: The subject_id of this AuthzGrant.
        :type: str
        """
        
        self._subject_id = subject_id

    @property
    def division(self):
        """
        Gets the division of this AuthzGrant.


        :return: The division of this AuthzGrant.
        :rtype: AuthzDivision
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this AuthzGrant.


        :param division: The division of this AuthzGrant.
        :type: AuthzDivision
        """
        
        self._division = division

    @property
    def role(self):
        """
        Gets the role of this AuthzGrant.


        :return: The role of this AuthzGrant.
        :rtype: AuthzGrantRole
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this AuthzGrant.


        :param role: The role of this AuthzGrant.
        :type: AuthzGrantRole
        """
        
        self._role = role

    @property
    def grant_made_at(self):
        """
        Gets the grant_made_at of this AuthzGrant.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The grant_made_at of this AuthzGrant.
        :rtype: datetime
        """
        return self._grant_made_at

    @grant_made_at.setter
    def grant_made_at(self, grant_made_at):
        """
        Sets the grant_made_at of this AuthzGrant.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param grant_made_at: The grant_made_at of this AuthzGrant.
        :type: datetime
        """
        
        self._grant_made_at = grant_made_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CampaignRuleActionEntities(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignRuleActionEntities - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'campaigns': 'list[DomainEntityRef]',
            'sequences': 'list[DomainEntityRef]',
            'use_triggering_entity': 'bool'
        }

        self.attribute_map = {
            'campaigns': 'campaigns',
            'sequences': 'sequences',
            'use_triggering_entity': 'useTriggeringEntity'
        }

        self._campaigns = None
        self._sequences = None
        self._use_triggering_entity = None

    @property
    def campaigns(self):
        """
        Gets the campaigns of this CampaignRuleActionEntities.
        The list of campaigns for a CampaignRule to monitor. Required if the CampaignRule has any conditions that run on a campaign.

        :return: The campaigns of this CampaignRuleActionEntities.
        :rtype: list[DomainEntityRef]
        """
        return self._campaigns

    @campaigns.setter
    def campaigns(self, campaigns):
        """
        Sets the campaigns of this CampaignRuleActionEntities.
        The list of campaigns for a CampaignRule to monitor. Required if the CampaignRule has any conditions that run on a campaign.

        :param campaigns: The campaigns of this CampaignRuleActionEntities.
        :type: list[DomainEntityRef]
        """
        
        self._campaigns = campaigns

    @property
    def sequences(self):
        """
        Gets the sequences of this CampaignRuleActionEntities.
        The list of sequences for a CampaignRule to monitor. Required if the CampaignRule has any conditions that run on a sequence.

        :return: The sequences of this CampaignRuleActionEntities.
        :rtype: list[DomainEntityRef]
        """
        return self._sequences

    @sequences.setter
    def sequences(self, sequences):
        """
        Sets the sequences of this CampaignRuleActionEntities.
        The list of sequences for a CampaignRule to monitor. Required if the CampaignRule has any conditions that run on a sequence.

        :param sequences: The sequences of this CampaignRuleActionEntities.
        :type: list[DomainEntityRef]
        """
        
        self._sequences = sequences

    @property
    def use_triggering_entity(self):
        """
        Gets the use_triggering_entity of this CampaignRuleActionEntities.
        If true, the CampaignRuleAction will apply to the same entity that triggered the CampaignRuleCondition.

        :return: The use_triggering_entity of this CampaignRuleActionEntities.
        :rtype: bool
        """
        return self._use_triggering_entity

    @use_triggering_entity.setter
    def use_triggering_entity(self, use_triggering_entity):
        """
        Sets the use_triggering_entity of this CampaignRuleActionEntities.
        If true, the CampaignRuleAction will apply to the same entity that triggered the CampaignRuleCondition.

        :param use_triggering_entity: The use_triggering_entity of this CampaignRuleActionEntities.
        :type: bool
        """
        
        self._use_triggering_entity = use_triggering_entity

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AdditionalMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AdditionalMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'text_body': 'str',
            'media_ids': 'list[str]',
            'sticker_ids': 'list[str]',
            'messaging_template': 'MessagingTemplateRequest'
        }

        self.attribute_map = {
            'text_body': 'textBody',
            'media_ids': 'mediaIds',
            'sticker_ids': 'stickerIds',
            'messaging_template': 'messagingTemplate'
        }

        self._text_body = None
        self._media_ids = None
        self._sticker_ids = None
        self._messaging_template = None

    @property
    def text_body(self):
        """
        Gets the text_body of this AdditionalMessage.
        The body of the text message.

        :return: The text_body of this AdditionalMessage.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this AdditionalMessage.
        The body of the text message.

        :param text_body: The text_body of this AdditionalMessage.
        :type: str
        """
        
        self._text_body = text_body

    @property
    def media_ids(self):
        """
        Gets the media_ids of this AdditionalMessage.
        The media ids associated with the text message.

        :return: The media_ids of this AdditionalMessage.
        :rtype: list[str]
        """
        return self._media_ids

    @media_ids.setter
    def media_ids(self, media_ids):
        """
        Sets the media_ids of this AdditionalMessage.
        The media ids associated with the text message.

        :param media_ids: The media_ids of this AdditionalMessage.
        :type: list[str]
        """
        
        self._media_ids = media_ids

    @property
    def sticker_ids(self):
        """
        Gets the sticker_ids of this AdditionalMessage.
        The sticker ids associated with the text message.

        :return: The sticker_ids of this AdditionalMessage.
        :rtype: list[str]
        """
        return self._sticker_ids

    @sticker_ids.setter
    def sticker_ids(self, sticker_ids):
        """
        Sets the sticker_ids of this AdditionalMessage.
        The sticker ids associated with the text message.

        :param sticker_ids: The sticker_ids of this AdditionalMessage.
        :type: list[str]
        """
        
        self._sticker_ids = sticker_ids

    @property
    def messaging_template(self):
        """
        Gets the messaging_template of this AdditionalMessage.
        The messaging template use to send a predefined canned response with the message

        :return: The messaging_template of this AdditionalMessage.
        :rtype: MessagingTemplateRequest
        """
        return self._messaging_template

    @messaging_template.setter
    def messaging_template(self, messaging_template):
        """
        Sets the messaging_template of this AdditionalMessage.
        The messaging template use to send a predefined canned response with the message

        :param messaging_template: The messaging_template of this AdditionalMessage.
        :type: MessagingTemplateRequest
        """
        
        self._messaging_template = messaging_template

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

